---
title: <span class="badge object-type-scalar"></span> GibibytesPerSecond
---
# <span class="badge object-type-scalar"></span> GibibytesPerSecond

Data rate: gibibytes/sec

## Definition

```python
# Data rate: gibibytes/sec
GibibytesPerSecond: typing.Literal["GiBs"] = "GiBs"
```
